calc.locs calculates likelihood estimates for each day of animal tag
data using tag-based locations.
calc.locs(locs, gps = NULL, iniloc, locs.grid, dateVec)is data frame from -Locations file output from DAP/Tag Portal for WC tags and contains GPS, Argos, and GPE locations as applicable.
is data frame from -FastGPS file output from WC Tag Portal
is 2 x 5 dataframe containing day, month, year, lat, lon for both tag and pop locations
is list output from setup.locs.grid
is vector of dates from tag to pop-up in 1 day increments.
L is an array of lon x lat likelihood surfaces (matrices) for each time point (3rd dimension)
GPS and Argos positions are given a "likelihood" using this function but are currently both considered to be "known" positions without error.