Calculate Ocean Heat Content (OHC) likelihood surface in parallel
calc.ohc.par(pdt, filename, isotherm = "", ohc.dir, dateVec, bathy = TRUE,
use.se = TRUE, ncores = NULL)input PDT data see extract.pdt
is the first part of the filename specified to the download
function get.env. For example, if downloaded files were
specific to a particular dataset, you may want to identify that with a name
like 'tuna' or 'shark1'. This results in a downloaded filename of, for
example, 'tuna_date.nc'. This filename is required here so the calc
function knows where to get the env data.
default '' in which isotherm is calculated on the fly based on daily tag data. Otherwise, numeric isotherm constraint can be specified (e.g. 20 deg C).
directory of downloaded hycom (or other) data
vector of complete dates for data range. This should be in 'Date' format
is logical indicating whether or not a bathymetric mask should be applied
is logical indicating whether or not to use SE when using regression to predict temperature at specific depth levels.
specify number of cores, or leave blank and use whatever you have!
a raster brick of OHC likelihood
Luo J, Ault JS, Shay LK, Hoolihan JP, Prince ED, Brown C a., Rooker JR (2015) Ocean Heat Content Reveals Secrets of Fish Migrations. PLoS One 10:e0141101