calc.srss calculates likelihood estimates for each day's estimated
dawn dusk times from the tag
calc.srss(light = NULL, locs.grid, dateVec, res = 1, focalDim = 3)is data frame from -LightLoc file output from DAP/Tag Portal for WC tags and contains tag-measured dawn/dusk times.
is list output from setup.locs.grid
is vector of dates from tag to pop-up in 1 day increments.
is resolution of light grid in degrees. default is 1 deg. higher resolution (e.g. res = .25 for 1/4 deg) takes considerably longer to compute
is integer for dimensions of raster::focal used to calculate sd() of SRSS grid cell. Recommend focalDim = 3 if res=1 and focalDim = 9 if res=0.25.
L is a raster of dim(lon x lat x dateVec) containing likelihood surfaces for each time point
Tag-measured sunrise/sunset (SRSS) times are first filtered according to the min/max times possible. possible values are computed based on spatial limits included in locs.grid input. after filtering, each yearday has a grid of georeferenced SRSS times that the tag-measured times are compared to in order to generate a likelihood.