powered by
calc.track uses HMM output via hmm.smoother to calculate most probable track and behavior state
calc.track
hmm.smoother
calc.track(distr, g, dateVec, iniloc, method = "mean")
is output array from hmm.smoother
is one of the outputs from resample.grid which denotes what spatial scale and grid you're working on
resample.grid
is vector of dates from tag to pop-up in 1 day increments.
is matrix of tag and pop locations. Default is NULL because this should be taken care of elsewhere.
is character indicating what method to use for track calculation. Currently only 'mean' and 'max' are supported.
calculated track
# NOT RUN { # GET THE MOST PROBABLE TRACK tr <- calc.track(s, g, dateVec, iniloc) # } # NOT RUN { # }
Run the code above in your browser using DataLab