Calculate Depth-temperature profile based likelihood
calc.woa(pdt, ptt, woa.data = NULL, dateVec, sp.lim = NULL,
focalDim = NULL, use.se = TRUE)input PDT data output from read.wc and
extract.pdt
is unique tag identifier
is (typically) a list of monthly global 1/4deg climatology
data from WOA13. See get.env.
is vector of dates from tag to pop-up in 1 day increments.
is list of limits as list(xmin, xmax, ymin, ymax)
is integer for dimensions of raster::focal used to calculate sd() of temperature grid cell. Recommend focalDim = 3 if woa.data = woa.one and 9 if using woa.quarter.
is logical indicating whether or not to use SE when using regression to predict temperature at specific depth levels.
raster brick of likelihood
calc.woa.par calculates likelihood of animal position based on
summarized depth-temperature profiles
Tag-based depth-temperature profile summaries are compared to climatological profiles from the World Ocean Atlas (WOA) "matched" to generate position likelihoods. This essentially attempts to estimate animal position based on the water mass it is in, particularly if extensive diving performs thorough sampling of the environment. However, remember the in situ data is being compared to climatological means or the results of an oceanographic model.