get.oi.sst downloads sea surface temperature (SST) data for given
temporal and spatial constraints of your data.
get.oi.sst(limits, time, filename = "", download.file = TRUE,
dir = getwd())A list of length 4; minlon, maxlon, minlat, maxlat. Longitude values are -180,180
A vector of length 2 with the minimum and maximum times in form
as.Date(date).
An optional filename. If provided, then the data is downloaded to that file. Otherwise the data is not downloaded and the url is returned.
Logical. Should use the default download.file to
query the server and download or use the optional curl. Some users
may need to use curl in order to get this to work.
is local directory where ncdf files should be downloaded to. default is current working directory. if enter a directory that doesn't exist, it will be created.
The url used to extract the requested data from the NetCDF subset service.
The method may return before the download is completed. It will continue to
display progress until the download completes. Change the default
download.file if the download is failing on your platform.