Learn R Programming

HMMoce (version 1.0.0)

hmm.smoother: Smoother recursion over filtered state estimates

Description

hmm.smoother provides backward (starting at end) recursion over filtered state estimates as output from hmm.filter. The product of this function an array containing final state estimates.

Usage

hmm.smoother(f, K1, K2, L, P)

Arguments

f

is array output from hmm.filter

K1

is movement kernel generated by gausskern for behavior state 1

K2

is movement kernel generated by gausskern for behavior state 2

L

is likelihood array output from make.L

P

is transition matrix (usually 2x2) representing probability of state switching

Value

an array of the final state estimates of dim(state, time, lon, lat)

References

Pedersen MW, Patterson TA, Thygesen UH, Madsen H (2011) Estimating animal behavior and residency from movement data. Oikos 120:1281-1290. doi: 10.1111/j.1600-0706.2011.19044.x

Examples

Run this code
# NOT RUN {
# Not run as function relies on large arrays of likelihoods
# RUN THE SMOOTHING STEP
s <- hmm.smoother(f, K1, K2, L, P.final)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab