Learn R Programming

HMMoce (version 1.0.0)

likint3: Calculate density function and integrate between limits

Description

#' likint3 calculates density function for a normal distribution and integrates between limits

Usage

likint3(w, wsd, minT, maxT)

Arguments

w

is an array of grid values like sea surface temperature

wsd

is an array containing the sd of the grid values, usually from raster::focal

minT

is an integer representing the lower limit of the tag-measured variable (e.g. SST)

maxT

is an integer representing the upper limit of the tag-measured variable

Value

an array of dim(w) that represents the likelihood of the tag-measured variable as compared to the input grid

Examples

Run this code
# NOT RUN {
# Dummy example environmental grid
env.grid <- matrix(seq(1,100,by=1), ncol=10)

# Generates likelihood of measurement
# as compared to environmental grid
likint3(env.grid, 2, 55, 70)
# }

Run the code above in your browser using DataLab