powered by
#' likint3 calculates density function for a normal distribution and integrates between limits
likint3
likint3(w, wsd, minT, maxT)
is an array of grid values like sea surface temperature
is an array containing the sd of the grid values, usually from raster::focal
raster::focal
is an integer representing the lower limit of the tag-measured variable (e.g. SST)
is an integer representing the upper limit of the tag-measured variable
an array of dim(w) that represents the likelihood of the tag-measured variable as compared to the input grid
# NOT RUN { # Dummy example environmental grid env.grid <- matrix(seq(1,100,by=1), ncol=10) # Generates likelihood of measurement # as compared to environmental grid likint3(env.grid, 2, 55, 70) # }
Run the code above in your browser using DataLab